@@ -3,7 +3,7 @@
 # Author:      Robin Dunn
 #
 # Created:     06-Jun-2012
-# Copyright:   (c) 2012-2018 by Total Control Software
+# Copyright:   (c) 2012-2020 by Total Control Software
 # License:     wxWindows License
 #---------------------------------------------------------------------------
 
@@ -43,12 +43,11 @@ def run():
     c = module.find('wxTreeListItem')
     assert isinstance(c, etgtools.ClassDef)
 
-    c.addCppMethod('int', '__nonzero__', '()', """\
-        return self->IsOk();
-        """)
+    c.addCppMethod('int', '__nonzero__', '()', "return self->IsOk();")
+    c.addCppMethod('int', '__bool__', '()', "return self->IsOk();")
 
     c.addCppMethod('long', '__hash__', '()', """\
-        return (long)self->GetID();
+        return (long)(intptr_t)self->GetID();
         """)
 
     c.addCppMethod('bool', '__eq__', '(wxTreeListItem* other)',
